==> exceptnotifier-0.2.2-py3-none-any.whl: ExceptNotifier/ipycore/sms_notifier_ipython.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 parkminwoo
import os
import datetime
from IPython.core.ultratb import AutoFormattedTB
from ExceptNotifier.base.sms_sender import send_sms_msg
from ExceptNotifier.base.openai_receiver import receive_openai_advice


DATE_FORMAT = "%Y-%m-%d %H:%M:%S"


def ExceptSMSIpython(
    shell: object, etype: object, evalue: object, tb: object, tb_offset=1
) -> None:
    """ExceptNotifier function for overriding custom execute in ipython for sending SMS.

    :param shell: Excecuted shell, ZMQInteractiveShell object.
    :type shell: object
    :param etype: Error type
    :type etype: object
    :param evalue: Error value
    :type evalue: object
    :param tb: TraceBack object of Ipython
    :type tb: object
    :param tb_offset: Offset of traceback, defaults to 1
    :type tb_offset: int, optional
    """
    itb = AutoFormattedTB(mode="Plain", tb_offset=1)
    shell.showtraceback((etype, evalue, tb), tb_offset=tb_offset)
    stb = itb.structured_traceback(etype, evalue, tb)
    sstb = itb.stb2text(stb)
    start_time = datetime.datetime.now()
    data = {
        "text": f"[Except Notifier] ** Error ** Python Code Exception Detected \n \n\nIMPORTANT WARNING \nPython Exception Detected in Your Code. \n\nHi there, \nThis is an exception catch notifier. \n\n * Code Status: Fail.🛠 \n * Detail: Python Code Ran Exceptions. \n * Time: {start_time.strftime(DATE_FORMAT)} \n\n ** {sstb}"
    }

    send_sms_msg(
        os.environ["_TWILIO_SID"],
        os.environ["_TWILIO_TOKEN"],
        os.environ["_SENDER_PHONE_NUMBER"],
        os.environ["_RECIPIENT_PHONE_NUMBER"],
        data["text"],
    )
    try:
        error_message = f"error sheel=={shell}, error_type_document=={etype.__doc__}, error_value=={evalue}, error message in ipython cell=={sstb}"
        advice_msg = receive_openai_advice(
            os.environ["_OPEN_AI_MODEL"], os.environ["_OPEN_AI_API"], error_message
        )
        send_sms_msg(
            os.environ["_TWILIO_SID"],
            os.environ["_TWILIO_TOKEN"],
            os.environ["_SENDER_PHONE_NUMBER"],
            os.environ["_RECIPIENT_PHONE_NUMBER"],
            advice_msg,
        )
    except Exception as e:
        print(e)
        pass

==> exceptnotifier-0.2.4-py3-none-any.whl: ExceptNotifier/ipycore/sms_notifier_ipython.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 parkminwoo
import datetime
from os import environ
from IPython.core.ultratb import AutoFormattedTB
from ExceptNotifier.base.sms_sender import send_sms_msg
from ExceptNotifier.base.openai_receiver import receive_openai_advice


DATE_FORMAT = "%Y-%m-%d %H:%M:%S"


def ExceptSMSIpython(
    shell: object, etype: object, evalue: object, tb: object, tb_offset=1
) -> None:
    """ExceptNotifier function for overriding custom execute in ipython for sending SMS.

    :param shell: Excecuted shell, ZMQInteractiveShell object.
    :type shell: object
    :param etype: Error type
    :type etype: object
    :param evalue: Error value
    :type evalue: object
    :param tb: TraceBack object of Ipython
    :type tb: object
    :param tb_offset: Offset of traceback, defaults to 1
    :type tb_offset: int, optional
    """
    itb = AutoFormattedTB(mode="Plain", tb_offset=1)
    shell.showtraceback((etype, evalue, tb), tb_offset=tb_offset)
    stb = itb.structured_traceback(etype, evalue, tb)
    sstb = itb.stb2text(stb)
    start_time = datetime.datetime.now()
    data = {
        "text": f"[Except Notifier] ** Error ** Python Code Exception Detected \n \n\nIMPORTANT WARNING \nPython Exception Detected in Your Code. \n\nHi there, \nThis is an exception catch notifier. \n\n * Code Status: Fail.🛠 \n * Detail: Python Code Ran Exceptions. \n * Time: {start_time.strftime(DATE_FORMAT)} \n\n ** {sstb}"
    }

    send_sms_msg(
        environ["_TWILIO_SID"],
        environ["_TWILIO_TOKEN"],
        environ["_SENDER_PHONE_NUMBER"],
        environ["_RECIPIENT_PHONE_NUMBER"],
        data["text"],
    )
    if environ.get('_OPEN_AI_API') is not None:
        try:
            error_message = f"error sheel=={shell}, error_type_document=={etype.__doc__}, error_value=={evalue}, error message in ipython cell=={sstb}"
            advice_msg = receive_openai_advice(
                environ["_OPEN_AI_MODEL"], environ["_OPEN_AI_API"], error_message
            )
            send_sms_msg(
                environ["_TWILIO_SID"],
                environ["_TWILIO_TOKEN"],
                environ["_SENDER_PHONE_NUMBER"],
                environ["_RECIPIENT_PHONE_NUMBER"],
                advice_msg,
            )
        except Exception as e:
            print(e)
            pass
